==> cdktf-cdktf-provider-google-0.6.1.tar.gz: package/lib/data-google-compute-resource-policy.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataGoogleComputeResourcePolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the resource, provided by the client when initially creating the resource.
     *
     * The resource name must be 1-63 characters long, and comply
     * with RFC1035. Specifically, the name must be 1-63 characters long and
     * match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])'? which means the
     * first character must be a lowercase letter, and all following characters
     * must be a dash, lowercase letter, or digit, except the last character,
     * which cannot be a dash.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_resource_policy#name DataGoogleComputeResourcePolicy#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_resource_policy#project DataGoogleComputeResourcePolicy#project}.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * Region where resource policy resides.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_resource_policy#region DataGoogleComputeResourcePolicy#region}
     *
     * @stability stable
     */
    readonly region?: string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicyGroupPlacementPolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get availabilityDomainCount(): number;
    /**
     * @stability stable
     */
    get collocation(): string;
    /**
     * @stability stable
     */
    get vmCount(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicyInstanceSchedulePolicyVmStartSchedule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get schedule(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicyInstanceSchedulePolicyVmStopSchedule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get schedule(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicyInstanceSchedulePolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get expirationTime(): string;
    /**
     * @stability stable
     */
    get startTime(): string;
    /**
     * @stability stable
     */
    get timeZone(): string;
    /**
     * @stability stable
     */
    get vmStartSchedule(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get vmStopSchedule(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicyRetentionPolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get maxRetentionDays(): number;
    /**
     * @stability stable
     */
    get onSourceDiskDelete(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicyScheduleDailySchedule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get daysInCycle(): number;
    /**
     * @stability stable
     */
    get startTime(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicyScheduleHourlySchedule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hoursInCycle(): number;
    /**
     * @stability stable
     */
    get startTime(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicyScheduleWeeklyScheduleDayOfWeeks extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get day(): string;
    /**
     * @stability stable
     */
    get startTime(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicyScheduleWeeklySchedule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get dayOfWeeks(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicySchedule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get dailySchedule(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get hourlySchedule(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get weeklySchedule(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicySnapshotProperties extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get guestFlush(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    get storageLocations(): string[];
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get retentionPolicy(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get schedule(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get snapshotProperties(): cdktf.IResolvable;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/d/compute_resource_policy google_compute_resource_policy}.
 *
 * @stability stable
 */
export declare class DataGoogleComputeResourcePolicy extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/d/compute_resource_policy google_compute_resource_policy} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataGoogleComputeResourcePolicyConfig);
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    groupPlacementPolicy(index: string): DataGoogleComputeResourcePolicyGroupPlacementPolicy;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    instanceSchedulePolicy(index: string): DataGoogleComputeResourcePolicyInstanceSchedulePolicy;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    /**
     * @stability stable
     */
    snapshotSchedulePolicy(index: string): DataGoogleComputeResourcePolicySnapshotSchedulePolicy;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.6.39.tar.gz: package/lib/data-google-compute-resource-policy.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleComputeResourcePolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the resource, provided by the client when initially creating
  the resource. The resource name must be 1-63 characters long, and comply
  with RFC1035. Specifically, the name must be 1-63 characters long and
  match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])'? which means the
  first character must be a lowercase letter, and all following characters
  must be a dash, lowercase letter, or digit, except the last character,
  which cannot be a dash.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_resource_policy#name DataGoogleComputeResourcePolicy#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_resource_policy#project DataGoogleComputeResourcePolicy#project}
    */
    readonly project?: string;
    /**
    * Region where resource policy resides.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_resource_policy#region DataGoogleComputeResourcePolicy#region}
    */
    readonly region?: string;
}
export declare class DataGoogleComputeResourcePolicyGroupPlacementPolicy extends cdktf.ComplexComputedList {
    get availabilityDomainCount(): number;
    get collocation(): string;
    get vmCount(): number;
}
export declare class DataGoogleComputeResourcePolicyInstanceSchedulePolicyVmStartSchedule extends cdktf.ComplexComputedList {
    get schedule(): string;
}
export declare class DataGoogleComputeResourcePolicyInstanceSchedulePolicyVmStopSchedule extends cdktf.ComplexComputedList {
    get schedule(): string;
}
export declare class DataGoogleComputeResourcePolicyInstanceSchedulePolicy extends cdktf.ComplexComputedList {
    get expirationTime(): string;
    get startTime(): string;
    get timeZone(): string;
    get vmStartSchedule(): cdktf.IResolvable;
    get vmStopSchedule(): cdktf.IResolvable;
}
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicyRetentionPolicy extends cdktf.ComplexComputedList {
    get maxRetentionDays(): number;
    get onSourceDiskDelete(): string;
}
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicyScheduleDailySchedule extends cdktf.ComplexComputedList {
    get daysInCycle(): number;
    get startTime(): string;
}
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicyScheduleHourlySchedule extends cdktf.ComplexComputedList {
    get hoursInCycle(): number;
    get startTime(): string;
}
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicyScheduleWeeklyScheduleDayOfWeeks extends cdktf.ComplexComputedList {
    get day(): string;
    get startTime(): string;
}
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicyScheduleWeeklySchedule extends cdktf.ComplexComputedList {
    get dayOfWeeks(): cdktf.IResolvable;
}
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicySchedule extends cdktf.ComplexComputedList {
    get dailySchedule(): cdktf.IResolvable;
    get hourlySchedule(): cdktf.IResolvable;
    get weeklySchedule(): cdktf.IResolvable;
}
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicySnapshotProperties extends cdktf.ComplexComputedList {
    get guestFlush(): cdktf.IResolvable;
    get labels(): {
        [key: string]: string;
    };
    get storageLocations(): string[];
}
export declare class DataGoogleComputeResourcePolicySnapshotSchedulePolicy extends cdktf.ComplexComputedList {
    get retentionPolicy(): cdktf.IResolvable;
    get schedule(): cdktf.IResolvable;
    get snapshotProperties(): cdktf.IResolvable;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google/d/compute_resource_policy google_compute_resource_policy}
*/
export declare class DataGoogleComputeResourcePolicy extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google/d/compute_resource_policy google_compute_resource_policy} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleComputeResourcePolicyConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleComputeResourcePolicyConfig);
    get description(): string;
    groupPlacementPolicy(index: string): DataGoogleComputeResourcePolicyGroupPlacementPolicy;
    get id(): string;
    instanceSchedulePolicy(index: string): DataGoogleComputeResourcePolicyInstanceSchedulePolicy;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    get selfLink(): string;
    snapshotSchedulePolicy(index: string): DataGoogleComputeResourcePolicySnapshotSchedulePolicy;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
